@@ -51,9 +51,7 @@ class DogecoinConnection(object):
     - *port* -- Dogecoin JSON-RPC port.
     """
 
-    def __init__(
-        self, user, password, host="localhost", port=22555, use_https=False
-    ):
+    def __init__(self, user, password, host="localhost", port=22555, use_https=False):
         """
         Create a new dogecoin server connection.
         """
@@ -211,9 +209,7 @@ class DogecoinConnection(object):
         """
         return self.proxy.getaddressesbyaccount(account)
 
-    def sendtoaddress(
-        self, dogecoinaddress, amount, comment=None, comment_to=None
-    ):
+    def sendtoaddress(self, dogecoinaddress, amount, comment=None, comment_to=None):
         """
         Sends *amount* from the server's available balance to *dogecoinaddress*.
 
@@ -231,9 +227,7 @@ class DogecoinConnection(object):
         elif comment_to is None:
             return self.proxy.sendtoaddress(dogecoinaddress, amount, comment)
         else:
-            return self.proxy.sendtoaddress(
-                dogecoinaddress, amount, comment, comment_to
-            )
+            return self.proxy.sendtoaddress(dogecoinaddress, amount, comment, comment_to)
 
     def getreceivedbyaddress(self, dogecoinaddress, minconf=1):
         """
@@ -297,7 +291,7 @@ class DogecoinConnection(object):
         - *mempool* -- Add memory pool transactions.
         """
         tx = self.proxy.gettxout(txid, index, mempool)
-        if tx != None:
+        if tx is not None:
             return TransactionInfo(**tx)
         else:
             return TransactionInfo()
@@ -325,9 +319,7 @@ class DogecoinConnection(object):
         """
         return self.proxy.createrawtransaction(inputs, outputs)
 
-    def signrawtransaction(
-        self, hexstring, previous_transactions=None, private_keys=None
-    ):
+    def signrawtransaction(self, hexstring, previous_transactions=None, private_keys=None):
         """
         Sign inputs for raw transaction (serialized, hex-encoded).
 
@@ -345,11 +337,7 @@ class DogecoinConnection(object):
         - *private_keys* -- A (possibly empty) list of base58-encoded private
             keys that, if given, will be the only keys used to sign the transaction.
         """
-        return dict(
-            self.proxy.signrawtransaction(
-                hexstring, previous_transactions, private_keys
-            )
-        )
+        return dict(self.proxy.signrawtransaction(hexstring, previous_transactions, private_keys))
 
     def decoderawtransaction(self, hexstring):
         """
@@ -363,9 +351,7 @@ class DogecoinConnection(object):
 
     def listsinceblock(self, block_hash):
         res = self.proxy.listsinceblock(block_hash)
-        res["transactions"] = [
-            TransactionInfo(**x) for x in res["transactions"]
-        ]
+        res["transactions"] = [TransactionInfo(**x) for x in res["transactions"]]
         return res
 
     def listreceivedbyaddress(self, minconf=1, includeempty=False):
@@ -380,10 +366,7 @@ class DogecoinConnection(object):
         - *includeempty* -- Whether to include addresses that haven't received any payments.
 
         """
-        return [
-            AddressInfo(**x)
-            for x in self.proxy.listreceivedbyaddress(minconf, includeempty)
-        ]
+        return [AddressInfo(**x) for x in self.proxy.listreceivedbyaddress(minconf, includeempty)]
 
     def listaccounts(self, minconf=1, as_dict=False):
         """
@@ -411,10 +394,7 @@ class DogecoinConnection(object):
 
         - *includeempty* -- Whether to include addresses that haven't received any payments.
         """
-        return [
-            AccountInfo(**x)
-            for x in self.proxy.listreceivedbyaccount(minconf, includeempty)
-        ]
+        return [AccountInfo(**x) for x in self.proxy.listreceivedbyaccount(minconf, includeempty)]
 
     def listtransactions(self, account=None, count=10, from_=0, address=None):
         """
@@ -430,11 +410,7 @@ class DogecoinConnection(object):
         - *from_* -- Skip the first <from_> transactions.
         - *address* -- Receive address to consider
         """
-        accounts = (
-            [account]
-            if account is not None
-            else self.listaccounts(as_dict=True).keys()
-        )
+        accounts = [account] if account is not None else self.listaccounts(as_dict=True).keys()
         return [
             TransactionInfo(**tx)
             for acc in accounts
@@ -498,9 +474,7 @@ class DogecoinConnection(object):
         if comment is None:
             return self.proxy.move(fromaccount, toaccount, amount, minconf)
         else:
-            return self.proxy.move(
-                fromaccount, toaccount, amount, minconf, comment
-            )
+            return self.proxy.move(fromaccount, toaccount, amount, minconf, comment)
 
     def sendfrom(
         self,
@@ -528,13 +502,9 @@ class DogecoinConnection(object):
 
         """
         if comment is None:
-            return self.proxy.sendfrom(
-                fromaccount, todogecoinaddress, amount, minconf
-            )
+            return self.proxy.sendfrom(fromaccount, todogecoinaddress, amount, minconf)
         elif comment_to is None:
-            return self.proxy.sendfrom(
-                fromaccount, todogecoinaddress, amount, minconf, comment
-            )
+            return self.proxy.sendfrom(fromaccount, todogecoinaddress, amount, minconf, comment)
         else:
             return self.proxy.sendfrom(
                 fromaccount,
@@ -565,21 +535,6 @@ class DogecoinConnection(object):
         else:
             return self.proxy.sendmany(fromaccount, todict, minconf, comment)
 
-    def verifymessage(self, dogecoinaddress, signature, message):
-        """
-        Verifies a signature given the dogecoinaddress used to sign,
-        the signature itself, and the message that was signed.
-        Returns :const:`True` if the signature is valid, and :const:`False` if it is invalid.
-
-        Arguments:
-
-        - *dogecoinaddress* -- the dogecoinaddress used to sign the message
-        - *signature* -- the signature to be verified
-        - *message* -- the message that was originally signed
-
-        """
-        return self.proxy.verifymessage(dogecoinaddress, signature, message)
-
     def getwork(self, data=None):
         """
         Get work for remote mining, or submit result.
@@ -611,10 +566,7 @@ class DogecoinConnection(object):
 
 
         """
-        return [
-            TransactionInfo(**tx)
-            for tx in self.proxy.listunspent(minconf, maxconf)
-        ]
+        return [TransactionInfo(**tx) for tx in self.proxy.listunspent(minconf, maxconf)]
 
     def keypoolrefill(self):
         "Fills the keypool, requires wallet passphrase to be set."
@@ -652,9 +604,7 @@ class DogecoinConnection(object):
         """
         return self.proxy.walletlock()
 
-    def walletpassphrasechange(
-        self, oldpassphrase, newpassphrase, dont_raise=False
-    ):
+    def walletpassphrasechange(self, oldpassphrase, newpassphrase, dont_raise=False):
         """
         Changes the wallet passphrase from <oldpassphrase> to <newpassphrase>.
 
@@ -673,13 +623,14 @@ class DogecoinConnection(object):
 
     def importprivkey(self, privkey, acct="", rescan=True):
         """
-        import private key <privkey> to account [acct], optionally rescanning blockchain .
+        Imports private key <privkey> to account [acct], optionally rescanning blockchain.
 
         Arguments:
 
         - *privkey* -- private key to import.
         - [acct] -- name of account to associate with private key
-        - [rescan] -- rescan blockchain for transcations containing altcoin address associated with privkey
+        - [rescan] -- rescan blockchain for transcations containing altcoin address
+            associated with privkey
         """
         return self.proxy.importprivkey(privkey, acct, rescan)
 
@@ -705,16 +656,18 @@ class DogecoinConnection(object):
         """
         return self.proxy.signmessage(address, message)
 
-    def verifymessage(self, address, signature, message):
+    def verifymessage(self, dogecoinaddress, signature, message):
         """
-        Verify a signed message
+        Verifies a signature given the dogecoinaddress used to sign,
+        the signature itself, and the message that was signed.
+        Returns :const:`True` if the signature is valid, and :const:`False` if it is invalid.
+
+        Arguments:
+
+        - *dogecoinaddress* -- the dogecoinaddress used to sign the message
+        - *signature* -- the signature to be verified
+        - *message* -- the message that was originally signed
 
-        :param address: Dogecoin address used to sign a message
-        :type address: str or unicode
-        :param signature: The signature
-        :type signature: unicode
-        :param message: The message to sign
-        :type message: str or unicode
         :rtype: bool
         """
-        return self.proxy.verifymessage(address, signature, message)
+        return self.proxy.verifymessage(dogecoinaddress, signature, message)
